from __future__ import absolute_import, unicode_literals
import os
import platform
from celery import Celery

# 将'your_project'替换为'automated_task_monitor'
os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'automated_task_monitor.settings')

# 同样这里改为正确的项目名
app = Celery('automated_task_monitor')

# 使用CELERY_前缀的设置
app.config_from_object('django.conf:settings', namespace='CELERY')

# 根据操作系统调整Celery配置
if platform.system() == 'Windows':
    # Windows 开发环境配置
    app.conf.update(
        worker_pool='eventlet',
        worker_concurrency=50,
    )
else:
    # Linux 生产环境配置
    app.conf.update(
        worker_concurrency=8,  # 设置为服务器CPU核心数
        worker_max_tasks_per_child=1000,  # 处理1000个任务后重启worker（防止内存泄漏）
        worker_prefetch_multiplier=4,  # 提前获取任务数量
    )

# 自动从所有注册的app中加载任务
app.autodiscover_tasks() 